@@ -34,7 +34,6 @@
 #include <libgnome/gnome-help.h>
 #include <libgnome/gnome-url.h>
 #include <libgnomeui/gnome-ui-init.h>
-#include <libgnomeui/gnome-authentication-manager.h>
 #include <libgnomevfs/gnome-vfs-utils.h>
 #include <profiles/gnome-media-profiles.h>
 #include <gst/gst.h>
@@ -353,8 +352,6 @@ static void update_ui_for_album (AlbumDetails *album)
     gtk_entry_set_text (GTK_ENTRY (artist_entry), album->artist);
     g_signal_handlers_unblock_by_func (title_entry, on_title_edit_changed, NULL);
     g_signal_handlers_unblock_by_func (artist_entry, on_artist_edit_changed, NULL);
-    /* Clear the genre field, it's from the user */
-    gtk_entry_set_text (GTK_ENTRY (genre_entry), "");
 
     gtk_widget_set_sensitive (title_entry, TRUE);
     gtk_widget_set_sensitive (artist_entry, TRUE);
@@ -424,7 +421,7 @@ AlbumDetails* multiple_album_dialog(GList *albums)
 
   if (dialog == NULL) {
     GtkTreeViewColumn *column;
-    GtkCellRenderer *text_renderer = gtk_cell_renderer_text_new ();
+    GtkCellRenderer *text_renderer = text_renderer = gtk_cell_renderer_text_new ();
 
     dialog = glade_xml_get_widget (glade, "multiple_dialog");
     g_assert (dialog != NULL);
@@ -564,6 +561,21 @@ void eject_changed_cb (GConfClient *client, guint cnxn_id, GConfEntry *entry, gp
   }
 }
 
+/**
+ * The GConf key for audio volume changes
+ */
+void audio_volume_changed_cb (GConfClient *client, guint cnxn_id, GConfEntry *entry, gpointer user_data)
+{
+  g_assert (strcmp (entry->key, GCONF_AUDIO_VOLUME) == 0);
+  
+ GtkWidget *volb = glade_xml_get_widget (glade, "volume_button");
+ if (entry->value == NULL) {
+    bacon_volume_button_set_value (BACON_VOLUME_BUTTON (volb), 1.0);
+  } else {
+  	bacon_volume_button_set_value (BACON_VOLUME_BUTTON (volb), gconf_value_get_float (entry->value));
+  }
+}
+
 static void
 metadata_cb (SjMetadata *m, GList *albums, GError *error)
 {
@@ -730,9 +742,6 @@ media_removed_cb (NautilusBurnDrive *drive,
     /* FIXME: recover? */
   }
 
-  /* first make sure we're not playing */
-  stop_playback ();
-  
   d(g_printerr ("** media removed from device %s\n", drive->device));
   stop_ui_hack ();
   update_ui_for_album (NULL);
@@ -1244,7 +1253,7 @@ int main (int argc, char **argv)
   bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
   textdomain (GETTEXT_PACKAGE);
 
-  ctx = g_option_context_new ("- Sound Juicer");
+  ctx = g_option_context_new (("- Extract music from your CDs"));
   g_option_context_add_main_entries (ctx, entries, GETTEXT_PACKAGE);  
   g_option_context_add_group (ctx, gst_init_get_option_group ());
   g_option_context_set_ignore_unknown_options (ctx, TRUE);
@@ -1258,8 +1267,6 @@ int main (int argc, char **argv)
 
   g_set_application_name (_("Sound Juicer"));
 
-  gnome_authentication_manager_init ();
-  
   sj_stock_init ();
 
   gtk_window_set_default_icon_name ("sound-juicer");
@@ -1298,6 +1305,7 @@ int main (int argc, char **argv)
   gconf_client_notify_add (gconf_client, GCONF_PARANOIA, paranoia_changed_cb, NULL, NULL, NULL);
   gconf_client_notify_add (gconf_client, GCONF_PATH_PATTERN, path_pattern_changed_cb, NULL, NULL, NULL);
   gconf_client_notify_add (gconf_client, GCONF_FILE_PATTERN, file_pattern_changed_cb, NULL, NULL, NULL);
+  gconf_client_notify_add (gconf_client, GCONF_AUDIO_VOLUME, audio_volume_changed_cb, NULL, NULL, NULL);
   gconf_client_add_dir (gconf_client, GCONF_PROXY_ROOT, GCONF_CLIENT_PRELOAD_RECURSIVE, NULL);
   gconf_client_notify_add (gconf_client, GCONF_HTTP_PROXY_ENABLE, http_proxy_enable_changed_cb, NULL, NULL, NULL);
   gconf_client_notify_add (gconf_client, GCONF_HTTP_PROXY, http_proxy_changed_cb, NULL, NULL, NULL);
@@ -1454,6 +1462,7 @@ int main (int argc, char **argv)
   paranoia_changed_cb (gconf_client, -1, gconf_client_get_entry (gconf_client, GCONF_PARANOIA, NULL, TRUE, NULL), NULL);
   strip_changed_cb (gconf_client, -1, gconf_client_get_entry (gconf_client, GCONF_STRIP, NULL, TRUE, NULL), NULL);
   eject_changed_cb (gconf_client, -1, gconf_client_get_entry (gconf_client, GCONF_EJECT, NULL, TRUE, NULL), NULL);
+  audio_volume_changed_cb (gconf_client, -1, gconf_client_get_entry (gconf_client, GCONF_AUDIO_VOLUME, NULL, TRUE, NULL), NULL);
   if (device == NULL) {
     device_changed_cb (gconf_client, -1, gconf_client_get_entry (gconf_client, GCONF_DEVICE, NULL, TRUE, NULL), GINT_TO_POINTER (TRUE));
   } else {
